<?php

namespace Teknisa\PLA\Modules\Parametros\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\Util\QuerySelector;
class SobrasController extends \Teknisa\GER\Controllers\TeknisaCrud {

	protected $dataSourceName;
	protected $parameterBagColumns;
    protected $dataSourceManager;
    protected $util;
    protected $connection;
    protected $novoCodigo;
    protected $environment;
    
    public function __construct($crudService, $parameterBag, $dataSourceManager, $util, $connection, $novoCodigo, $environment) {
        $this->crudService       = $crudService;
        $this->parameterBag      = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->util              = $util;
        $this->connection        = $connection;
        $this->novoCodigo        = $novoCodigo;
        $this->environment       = $environment;
    }
    
    public function saveMetaUnidServ($requrest, $response) {
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
        $row = $requrest->getRow();
        try {
            $lista = $this->novoCodigo->getCodeByTableName("LISTA", $this->environment->getNrOrg());
            
            foreach($row['FILISERV'] as $filiserv) {
                $this->insertLista($lista, $filiserv);
            }
            foreach($row['FILIAIS'] as $filis) {
                $this->insertLista($lista, $filis);
            }
            $queryOracle = "
                    SELECT CDFILIAL, CDSERVFILI
                    FROM METATIPOSOBRA MTS 
                         JOIN LISTA L 
                            ON L.NRLISTA = :NRLISTA 
                            AND L.CDLISTA = MTS.CDFILIAL||NVL(MTS.CDSERVFILI,'') 
                    WHERE MTS.NRTIPOSOBRA = :NRTIPOSOBRA";
            $queryPostgre =" 
                    SELECT CDFILIAL AS \"CDFILIAL\", CDSERVFILI AS \"CDSERVFILI\"
                    FROM METATIPOSOBRA MTS 
                         JOIN LISTA L 
                            ON L.NRLISTA = :NRLISTA 
                            AND L.CDLISTA = MTS.CDFILIAL||COALESCE(MTS.CDSERVFILI,'') 
                    WHERE MTS.NRTIPOSOBRA = :NRTIPOSOBRA";
                    
            $params = array(
                "NRLISTA" => $lista, 
                "NRTIPOSOBRA"=> $row['NRTIPOSOBRA']
            );
            $arrayQueries = array (
            'default'   => $queryOracle,
            'pdo_pgsql' => $queryPostgre
            );
            $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
    // 		$query = $this->connection->prepare($sql);
            // $query->execute($params);
            $result = $connection->fetchAll($query, $params);
            foreach($result as $metatipo) {
                if($metatipo['CDSERVFILI']) {
                    foreach($row['NMSERVICO'] as $key => $servicos) {
                        if($servicos['CDFILIAL'] == $metatipo['CDFILIAL'] && $servicos['CDSERVFILI'] == $metatipo['CDSERVFILI']) {
                            unset($row['NMSERVICO'][$key]);
                        }
                    }
                } else {
                    $index = array_search($metatipo['CDFILIAL'], $row['FILIAIS']);
                    unset($row['FILIAIS'][$index]);
                }
            }
            
            $dataSet = array();
            if(sizeof($row['NMSERVICO']) > 0) {
                foreach($row['NMSERVICO'] as $servico) {
                    $rowToSave = array();
                    $rowToSave['__is_new']        = $row['__is_new'];
                    $rowToSave['CDFILIAL']        = $servico['CDFILIAL'];
                    $rowToSave['CDSERVFILI']      = $servico['CDSERVFILI'];
                    $rowToSave['NRTIPOSOBRA']     = $row['NRTIPOSOBRA'];
                    $rowToSave['VRMETATIPOSOBRA'] = $row['VRMETATIPOSOBRA'];
                    $rowToSave['NRMETATIPOSOBRA'] = $this->novoCodigo->getCodeByTableName("METATIPOSOBRA", $this->environment->getNrOrg());
                    array_push($dataSet, $rowToSave);
                }
            }
            foreach($row['FILIAIS'] as $filial) {
                $rowToSave = array();
                $rowToSave['__is_new']        = $row['__is_new'];
                $rowToSave['CDFILIAL']        = $filial;
                $rowToSave['NRTIPOSOBRA']     = $row['NRTIPOSOBRA'];
                $rowToSave['CDSERVFILI']      = null;
                $rowToSave['VRMETATIPOSOBRA'] = $row['VRMETATIPOSOBRA'];
                $rowToSave['NRMETATIPOSOBRA'] = $this->novoCodigo->getCodeByTableName("METATIPOSOBRA", $this->environment->getNrOrg());
                array_push($dataSet, $rowToSave);
            }
            $dataSet = new DataSet('metatiposobra', $dataSet);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            $rowsToSave = $this->crudService->getRowsToSave($request, 'metatiposobra');
            $this->crudService->save('metatiposobra', $rowsToSave);
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function deleteLista($nrlista) {
        $params = array(
            "NRLISTA" => $nrlista
        );
        
        $sql = "DELETE FROM LISTA WHERE NRLISTA =:NRLISTA";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }

 }